@@ -71,7 +71,7 @@ def ProcessFiles(sourceFile):
         sourceContent = (file.read())
         file.close()
         for i in range (len(targetLangs)):
-            print('\033[92m {}\033[00m'.format('\rTraslating "' + sourceFile + '" from "' + sourceLang + '" to "' + targetLangs[i] + '"'), end='')
+            PrGreen('Traslating "' + sourceFile + '" from "' + sourceLang + '" to "' + targetLangs[i] + '"')
             langCombo = sourceLang + '-' + targetLangs[i]
             targetContent = ''
             if fileName[-3:] == 'yml':
@@ -118,7 +118,7 @@ def ProcessFiles(sourceFile):
             file.write(targetContent)
             file.close()
         return
-    print('\033[94m {}\033[00m'.format('\rCopying "' + sourceFile + '"'), end='')
+    PrLightPurple('Copying "' + sourceFile + '"')
     for i in range (len(targetLangs)):
         shutil.copy(sourceFile, targetPaths[i] + '/' + '/'.join(sourceFile.split('/')[1:]))
 
